==> portal-contribuinte-3.049.0.zip: BOOT-INF/classes/br/com/elotech/tributos/calculo/repository/load-cadastro-isencao.sql <==
select cadastroisencao.tribcadastrogeral_idkey as idCadastro,
       isencao.isencao,
       case
         when isencao.isentoimposto = 'S' then
          1
         else
          0
       end isentoimposto,
       case
         when isencao.reducaoimposto = 'S' then
          1
         else
          0
       end reducaoimposto,
       isencao.valorreducaoimposto,
       case
         when isencao.isentotaxa = 'S' then
          1
         else
          0
       end isentotaxa,
       case
         when isencao.reducaotaxa = 'S' then
          1
         else
          0
       end reducaotaxa,
       isencao.valorreducaotaxa,
       case
         when isencao.isentocontribuicao = 'S' then
          1
         else
          0
       end isentocontribuicao,
       case
         when isencao.reducaocontribuicao = 'S' then
          1
         else
          0
       end reducaocontribuicao,
       isencao.valorreducaocontribuicao,
       case
         when isencao.isentornt = 'S' then
          1
         else
          0
       end isentoReceitasNaoTributaveis,
       case
         when isencao.reducaornt = 'S' then
          1
         else
          0
       end reducaoReceitasNaoTributaveis,
       isencao.valorreducaornt as valorReducaoReceitasNaoTrib
  from tribcadastrogeral cadastrogeral
  left join tribcadastroimobiliario cadastroimobiliario
    on cadastrogeral.cadastrogeral = cadastroimobiliario.cadastrogeral
   and cadastrogeral.tipocadastro = cadastroimobiliario.tipocadastro
  left join tribcadastromobiliario cadastromobiliario
      on cadastrogeral.cadastrogeral = cadastromobiliario.cadastrogeral
     and cadastrogeral.tipocadastro = cadastromobiliario.tipocadastro
  join tribcadastrogeralisencao cadastroisencao
    on (cadastrogeral.tipocadastro = cadastroisencao.tipocadastro and
       cadastrogeral.cadastrogeral = cadastroisencao.cadastrogeral)
  join tribisencao isencao
    on (cadastroisencao.isencao = isencao.isencao)
 where %s
 and cadastrogeral.exclusaologica = 'N'
 and isencao.inativo = 'N'
 and :exercicio between coalesce(cadastroisencao.anoisencao, :exercicio) and coalesce(cadastroisencao.fimisencao, :exercicio)

==> portal-contribuinte-3.162.0.zip: BOOT-INF/classes/br/com/elotech/tributos/calculo/repository/load-cadastro-isencao.sql <==
select cadastroisencao.tribcadastrogeral_idkey as idCadastro,
       isencao.isencao,
       case
         when isencao.isentoimposto = 'S' then
          1
         else
          0
       end isentoimposto,
       case
         when isencao.reducaoimposto = 'S' then
          1
         else
          0
       end reducaoimposto,
       isencao.valorreducaoimposto,
       case
         when isencao.isentotaxa = 'S' then
          1
         else
          0
       end isentotaxa,
       case
         when isencao.reducaotaxa = 'S' then
          1
         else
          0
       end reducaotaxa,
       isencao.valorreducaotaxa,
       case
         when isencao.isentocontribuicao = 'S' then
          1
         else
          0
       end isentocontribuicao,
       case
         when isencao.reducaocontribuicao = 'S' then
          1
         else
          0
       end reducaocontribuicao,
       isencao.valorreducaocontribuicao,
       case
         when isencao.isentornt = 'S' then
          1
         else
          0
       end isentoReceitasNaoTributaveis,
       case
         when isencao.reducaornt = 'S' then
          1
         else
          0
       end reducaoReceitasNaoTributaveis,
       isencao.valorreducaornt as valorReducaoReceitasNaoTrib
  from tribcadastrogeral cadastrogeral
  left join tribcadastroimobiliario cadastroimobiliario
    on cadastrogeral.cadastrogeral = cadastroimobiliario.cadastrogeral
   and cadastrogeral.tipocadastro = cadastroimobiliario.tipocadastro
  left join tribcadastromobiliario cadastromobiliario
      on cadastrogeral.cadastrogeral = cadastromobiliario.cadastrogeral
     and cadastrogeral.tipocadastro = cadastromobiliario.tipocadastro
  left join tribcadastrorural cadastrorural
     on cadastrogeral.cadastrogeral = cadastrorural.cadastrogeral and
         cadastrogeral.tipocadastro = cadastrorural.tipocadastro
  join tribcadastrogeralisencao cadastroisencao
    on (cadastrogeral.tipocadastro = cadastroisencao.tipocadastro and
       cadastrogeral.cadastrogeral = cadastroisencao.cadastrogeral)
  join tribisencao isencao
    on (cadastroisencao.isencao = isencao.isencao)
 where %s
 and cadastrogeral.exclusaologica = 'N'
 and isencao.inativo = 'N'
 and :exercicio between coalesce(cadastroisencao.anoisencao, :exercicio) and coalesce(cadastroisencao.fimisencao, :exercicio)
